@@ -9,14 +9,14 @@ extends 'Code::TidyAll::Plugin';
 
 with 'Code::TidyAll::Role::GenericExecutable';
 
-our $VERSION = '0.75';
+our $VERSION = '0.78';
 
 sub transform_file {
     my $self = shift;
     my $file = shift;
 
     my $output = $self->_run_generic_executable_or_die($file);
-    $file->spew($output);
+    $file->spew_raw($output);
 
     return;
 }
@@ -38,7 +38,7 @@ transformer
 
 =head1 VERSION
 
-version 0.75
+version 0.78
 
 =head1 SYNOPSIS
 
@@ -111,7 +111,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2020 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
