@@ -25,7 +25,7 @@ sub test_git : Tests {
     my ( $temp_dir, $work_dir, $pushd ) = $self->_make_working_dir_and_repo;
 
     subtest 'add foo.txt', sub {
-        $work_dir->child('foo.txt')->spew("abc\n");
+        $work_dir->child('foo.txt')->spew_raw("abc\n");
         cmp_deeply( [ git_files_to_commit($work_dir) ], [], 'no files to commit' );
 
         runx(qw( git add foo.txt ));
@@ -43,14 +43,14 @@ sub test_git : Tests {
     };
 
     subtest 'successfully commit tidied file', sub {
-        $work_dir->child('foo.txt')->spew("ABC\n");
+        $work_dir->child('foo.txt')->spew_raw("ABC\n");
         my $output = capture_stderr { runx(qw( git commit -q -m changed -a )) };
         like( $output, qr/\[checked\] foo\.txt/, 'checked foo.txt' );
         $self->_assert_nothing_to_commit($work_dir);
     };
 
     subtest 'add another file which is tidied', sub {
-        $work_dir->child('bar.txt')->spew('ABC');
+        $work_dir->child('bar.txt')->spew_raw('ABC');
         runx(qw( git add bar.txt ));
         runx(qw( git commit -q -m bar.txt ));
 
@@ -80,7 +80,7 @@ sub test_git : Tests {
     $prereceive_hook_file->chmod(0775);
 
     subtest 'untidy file and attempt to commit it via commit -a', sub {
-        $clone_dir->child('foo.txt')->spew("def\n");
+        $clone_dir->child('foo.txt')->spew_raw("def\n");
         runx(qw( git commit -q -m changed -a ));
         $self->_assert_nothing_to_commit($work_dir);
         $self->_assert_branch_is_ahead_of_origin;
@@ -95,7 +95,7 @@ sub test_git : Tests {
     };
 
     subtest 'can push tidied file', sub {
-        $clone_dir->child('foo.txt')->spew("DEF\n");
+        $clone_dir->child('foo.txt')->spew_raw("DEF\n");
         capture_stderr { runx(qw( git commit -q -m changed -a )) };
         $self->_assert_nothing_to_commit($work_dir);
         my $output = capture_stderr { system(qw( git push )) };
@@ -104,7 +104,7 @@ sub test_git : Tests {
     };
 
     subtest 'untidy file and commit it', sub {
-        $clone_dir->child('foo.txt')->spew("def\n");
+        $clone_dir->child('foo.txt')->spew_raw("def\n");
         runx(qw( git commit -q -m changed -a ));
         $self->_assert_nothing_to_commit($work_dir);
         $self->_assert_branch_is_ahead_of_origin;
@@ -126,15 +126,6 @@ sub test_git : Tests {
     };
 }
 
-sub _quote_for_win32 {
-
-    # The docs for IPC::System::Simple lie about how it works on Windows. On
-    # Windows it _always_ invokes a shell, so we need to quote a path with
-    # spaces.
-    return $_[0] unless IS_WIN32 && $_[0] =~ / /;
-    return qq{"$_[0]"};
-}
-
 sub test_copied_status : Tests {
     my ($self) = @_;
 
@@ -144,14 +135,14 @@ sub test_copied_status : Tests {
 
     # If the file isn't long enough the new file doesn't end up with the
     # "copied" status.
-    $foo_file->spew( "ABC\n" x 500 );
+    $foo_file->spew_raw( "ABC\n" x 500 );
 
     runx(qw( git add foo.txt ));
     runx(qw( git commit -m foo ));
 
     my $bar_file = $work_dir->child('bar.txt');
-    $bar_file->spew( "ABC\n" x 500 );
-    $foo_file->spew(q{});
+    $bar_file->spew_raw( "ABC\n" x 500 );
+    $foo_file->spew_raw(q{});
 
     runx(qw( git add foo.txt bar.txt ));
     my $output = capture_stderr { runx(qw( git commit -m bar )) };
@@ -168,10 +159,10 @@ sub test_precommit_stash_issues : Tests {
     my ( $temp_dir, $work_dir, $pushd ) = $self->_make_working_dir_and_repo;
 
     my $foo_file = $work_dir->child('foo.txt');
-    $foo_file->spew("ABC\n");
+    $foo_file->spew_raw("ABC\n");
 
     my $bar_file = $work_dir->child('bar.txt');
-    $bar_file->spew("DEF\n");
+    $bar_file->spew_raw("DEF\n");
 
     subtest 'commit two tidy files', sub {
         $self->_assert_something_to_commit($work_dir);
@@ -182,8 +173,8 @@ sub test_precommit_stash_issues : Tests {
         $self->_assert_nothing_to_commit($work_dir);
     };
 
-    $foo_file->spew("abc\n");
-    $bar_file->spew("abc\n");
+    $foo_file->spew_raw("abc\n");
+    $bar_file->spew_raw("abc\n");
 
     subtest 'cannot commit untidy files', sub {
         $self->_assert_something_to_commit($work_dir);
@@ -196,10 +187,10 @@ sub test_precommit_stash_issues : Tests {
         $self->_assert_something_to_commit($work_dir);
     };
 
-    $foo_file->spew("ABC\n");
+    $foo_file->spew_raw("ABC\n");
 
     my $baz_file = $work_dir->child('baz.txt');
-    $baz_file->spew("ABC\n");
+    $baz_file->spew_raw("ABC\n");
 
     subtest 'commit one valid file and working directory is left intact', sub {
         runx(qw( git add foo.txt ));
@@ -224,7 +215,7 @@ sub test_precommit_stash_issues : Tests {
         );
     };
 
-    $foo_file->spew("abc\n");
+    $foo_file->spew_raw("abc\n");
     subtest 'commit one invalid file and working directory is left intact', sub {
         runx(qw( git add foo.txt ));
         my ( undef, $stderr ) = capture( sub { system(qw( git commit -q -m foo )) } );
@@ -256,11 +247,11 @@ sub test_precommit_stash_issues : Tests {
 
     # We need to add to the stash so we can make sure that it's not popped
     # incorrectly later.
-    $foo_file->spew("abC\n");
+    $foo_file->spew_raw("abC\n");
     runx(qw( git stash -q ));
 
     subtest 'precommit hook does not pop when it did not stash', sub {
-        $foo_file->spew("ABCD\n");
+        $foo_file->spew_raw("ABCD\n");
         runx(qw( git commit -q -a -m changed ));
 
         # The bug we're fixing is that this commit would always pop the stash,
@@ -278,6 +269,49 @@ sub test_precommit_stash_issues : Tests {
     };
 }
 
+# See https://github.com/houseabsolute/perl-code-tidyall/issues/100 for the
+# bug we're testing.
+sub test_precommit_no_stash_merge : Tests {
+    my ($self) = @_;
+
+    my ( $temp_dir, $work_dir, $pushd ) = $self->_make_working_dir_and_repo;
+
+    $work_dir->child('file1.txt')->spew("A\nB\n");
+    $work_dir->child('file2.txt')->spew("A\nB\n");
+    runx(qw( git add file1.txt file2.txt ));
+    runx( qw( git commit -m ), 'Add files in master' );
+
+    $work_dir->child('file1.txt')->append("C\n");
+    $work_dir->child('file2.txt')->append("C\n");
+    runx( qw( git commit -a -m ), 'Update files in master' );
+
+    runx(qw( git checkout -b my-branch ));
+    runx(qw( git reset --hard HEAD~1 ));
+
+    $work_dir->child('file1.txt')->append("D\n");
+    $work_dir->child('file2.txt')->append("C\n");
+    runx(qw( git add file1.txt file2.txt ));
+    runx( qw( git commit  -m ), 'Update files in my-branch' );
+
+    # This will exit with 1 because of the conflict.
+    runx( [1], qw( git merge master ) );
+
+    like(
+        $work_dir->child(qw( .git MERGE_MSG ))->slurp,
+        qr/Conflicts:.+file1\.txt/s,
+        'merge produced a conflict with file.txt'
+    );
+
+    $work_dir->child('file1.txt')->spew("A\nB\nD\n");
+
+    # We need a change that will be stashed to trigger the bug.
+    $work_dir->child('file2.txt')->append("E\n");
+    runx(qw( git add file1.txt ));
+    runx( qw( git commit -m ), 'Add file1.txt in my-branch for real' );
+    my $output = capturex(qw( git log -n 1 ));
+    like( $output, qr/Merge: [0-9a-f]+ [0-9a-f]+/, 'last commit was a merge commit' );
+}
+
 sub _make_working_dir_and_repo {
     my $self = shift;
 
@@ -309,6 +343,15 @@ sub _make_working_dir_and_repo {
     return ( $temp_dir, $work_dir, $pushd );
 }
 
+sub _quote_for_win32 {
+
+    # The docs for IPC::System::Simple lie about how it works on Windows. On
+    # Windows it _always_ invokes a shell, so we need to quote a path with
+    # spaces.
+    return $_[0] unless IS_WIN32 && $_[0] =~ / /;
+    return qq{"$_[0]"};
+}
+
 sub _lib_dirs {
     join q{ }, map { $Cwd->child($_) } qw( lib t/lib );
 }
